@@ -9,13 +9,21 @@ import (
 func GetCommands() *core.Commands {
 	cmds := GetGeneratedCommands()
 
+	cmds.MustFind("baremetal").Groups = []string{"baremetal"}
+
 	cmds.Merge(core.NewCommands(
 		serverWaitCommand(),
 		serverAddFlexibleIP(),
 	))
 
-	human.RegisterMarshalerFunc(baremetal.ServerPingStatus(""), human.EnumMarshalFunc(serverPingStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(baremetal.OfferStock(""), human.EnumMarshalFunc(offerAvailabilityMarshalSpecs))
+	human.RegisterMarshalerFunc(
+		baremetal.ServerPingStatus(""),
+		human.EnumMarshalFunc(serverPingStatusMarshalSpecs),
+	)
+	human.RegisterMarshalerFunc(
+		baremetal.OfferStock(""),
+		human.EnumMarshalFunc(offerAvailabilityMarshalSpecs),
+	)
 	human.RegisterMarshalerFunc(baremetal.Server{}, serverMarshalerFunc)
 
 	human.RegisterMarshalerFunc(baremetal.Offer{}, listOfferMarshalerFunc)
