@@ -17,7 +17,9 @@ import (
 
 // deleteServerAfterFunc deletes the created server and its attached volumes and IPs.
 func deleteServerAfterFunc() core.AfterFunc {
-	return core.ExecAfterCmd("scw instance server delete {{ .CmdResult.ID }} with-volumes=all with-ip=true force-shutdown=true")
+	return core.ExecAfterCmd(
+		"scw instance server delete {{ .CmdResult.ID }} with-volumes=all with-ip=true force-shutdown=true",
+	)
 }
 
 // All test below should succeed to create an instance.
@@ -34,7 +36,11 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					assert.Equal(t, "Ubuntu 22.04 Jammy Jellyfish", ctx.Result.(*instanceSDK.Server).Image.Name)
+					assert.Equal(
+						t,
+						"Ubuntu 22.04 Jammy Jellyfish",
+						ctx.Result.(*instanceSDK.Server).Image.Name,
+					)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -77,7 +83,11 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					assert.Equal(t, instanceSDK.ServerStateRunning, ctx.Result.(*instanceSDK.Server).State)
+					assert.Equal(
+						t,
+						instanceSDK.ServerStateRunning,
+						ctx.Result.(*instanceSDK.Server).State,
+					)
 				},
 			),
 			AfterFunc: deleteServerAfterFunc(),
@@ -90,7 +100,11 @@ func Test_CreateServer(t *testing.T) {
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
 					assert.NotNil(t, ctx.Result)
-					assert.Equal(t, "Ubuntu Bionic Beaver", ctx.Result.(*instanceSDK.Server).Image.Name)
+					assert.Equal(
+						t,
+						"Ubuntu Bionic Beaver",
+						ctx.Result.(*instanceSDK.Server).Image.Name,
+					)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -127,7 +141,12 @@ func Test_CreateServer(t *testing.T) {
 					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
 					volume := testhelpers.MapTValue(t, server.Volumes, "0")
 					size := volume.Size
-					assert.Equal(t, 20*scw.GB, instance.SizeValue(size), "Size of volume should be 20 GB")
+					assert.Equal(
+						t,
+						20*scw.GB,
+						instance.SizeValue(size),
+						"Size of volume should be 20 GB",
+					)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -137,10 +156,18 @@ func Test_CreateServer(t *testing.T) {
 		t.Run("valid single local snapshot", core.Test(&core.TestConfig{
 			Commands: instance.GetCommands(),
 			BeforeFunc: core.BeforeFuncCombine(
-				core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu_bionic root-volume=local:20GB stopped=true")),
-				core.ExecStoreBeforeCmd("Snapshot", `scw instance snapshot create volume-id={{ (index .Server.Volumes "0").ID }}`),
+				core.ExecStoreBeforeCmd(
+					"Server",
+					testServerCommand("image=ubuntu_bionic root-volume=local:20GB stopped=true"),
+				),
+				core.ExecStoreBeforeCmd(
+					"Snapshot",
+					`scw instance snapshot create volume-id={{ (index .Server.Volumes "0").ID }}`,
+				),
+			),
+			Cmd: testServerCommand(
+				"image=ubuntu_bionic root-volume=local:{{ .Snapshot.Snapshot.ID }} stopped=true",
 			),
-			Cmd: testServerCommand("image=ubuntu_bionic root-volume=local:{{ .Snapshot.Snapshot.ID }} stopped=true"),
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
@@ -149,7 +176,12 @@ func Test_CreateServer(t *testing.T) {
 					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
 					volume := testhelpers.MapTValue(t, server.Volumes, "0")
 					size := volume.Size
-					assert.Equal(t, 20*scw.GB, instance.SizeValue(size), "Size of volume should be 20 GB")
+					assert.Equal(
+						t,
+						20*scw.GB,
+						instance.SizeValue(size),
+						"Size of volume should be 20 GB",
+					)
 				},
 			),
 			AfterFunc: core.AfterFuncCombine(
@@ -162,10 +194,18 @@ func Test_CreateServer(t *testing.T) {
 		t.Run("valid single local snapshot without image", core.Test(&core.TestConfig{
 			Commands: instance.GetCommands(),
 			BeforeFunc: core.BeforeFuncCombine(
-				core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu_bionic root-volume=local:20GB stopped=true")),
-				core.ExecStoreBeforeCmd("Snapshot", `scw instance snapshot create volume-id={{ (index .Server.Volumes "0").ID }}`),
+				core.ExecStoreBeforeCmd(
+					"Server",
+					testServerCommand("image=ubuntu_bionic root-volume=local:20GB stopped=true"),
+				),
+				core.ExecStoreBeforeCmd(
+					"Snapshot",
+					`scw instance snapshot create volume-id={{ (index .Server.Volumes "0").ID }}`,
+				),
+			),
+			Cmd: testServerCommand(
+				"image=none root-volume=local:{{ .Snapshot.Snapshot.ID }} stopped=true",
 			),
-			Cmd: testServerCommand("image=none root-volume=local:{{ .Snapshot.Snapshot.ID }} stopped=true"),
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
@@ -174,7 +214,12 @@ func Test_CreateServer(t *testing.T) {
 					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
 					volume := testhelpers.MapTValue(t, server.Volumes, "0")
 					size := volume.Size
-					assert.Equal(t, 20*scw.GB, instance.SizeValue(size), "Size of volume should be 20 GB")
+					assert.Equal(
+						t,
+						20*scw.GB,
+						instance.SizeValue(size),
+						"Size of volume should be 20 GB",
+					)
 				},
 			),
 			AfterFunc: core.AfterFuncCombine(
@@ -186,7 +231,9 @@ func Test_CreateServer(t *testing.T) {
 
 		t.Run("valid double local volumes", core.Test(&core.TestConfig{
 			Commands: instance.GetCommands(),
-			Cmd:      testServerCommand("image=ubuntu_bionic root-volume=local:10GB additional-volumes.0=l:10G stopped=true"),
+			Cmd: testServerCommand(
+				"image=ubuntu_bionic root-volume=local:10GB additional-volumes.0=l:10G stopped=true",
+			),
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
@@ -194,8 +241,18 @@ func Test_CreateServer(t *testing.T) {
 					server := testhelpers.Value[*instanceSDK.Server](t, ctx.Result)
 					size0 := testhelpers.MapTValue(t, server.Volumes, "0").Size
 					size1 := testhelpers.MapTValue(t, server.Volumes, "1").Size
-					assert.Equal(t, 10*scw.GB, instance.SizeValue(size0), "Size of volume should be 10 GB")
-					assert.Equal(t, 10*scw.GB, instance.SizeValue(size1), "Size of volume should be 10 GB")
+					assert.Equal(
+						t,
+						10*scw.GB,
+						instance.SizeValue(size0),
+						"Size of volume should be 10 GB",
+					)
+					assert.Equal(
+						t,
+						10*scw.GB,
+						instance.SizeValue(size1),
+						"Size of volume should be 10 GB",
+					)
 				},
 				core.TestCheckExitCode(0),
 			),
@@ -208,10 +265,18 @@ func Test_CreateServer(t *testing.T) {
 				block.GetCommands(),
 			),
 			BeforeFunc: core.BeforeFuncCombine(
-				core.ExecStoreBeforeCmd("Server", testServerCommand("image=ubuntu_jammy root-volume=block:20GB stopped=true")),
-				core.ExecStoreBeforeCmd("Snapshot", `scw block snapshot create volume-id={{ (index .Server.Volumes "0").ID }} -w`),
+				core.ExecStoreBeforeCmd(
+					"Server",
+					testServerCommand("image=ubuntu_jammy root-volume=block:20GB stopped=true"),
+				),
+				core.ExecStoreBeforeCmd(
+					"Snapshot",
+					`scw block snapshot create volume-id={{ (index .Server.Volumes "0").ID }} -w`,
+				),
+			),
+			Cmd: testServerCommand(
+				"image=ubuntu_jammy root-volume=block:{{ .Snapshot.ID }} additional-volumes.0=block:{{ .Snapshot.ID }} stopped=true",
 			),
-			Cmd: testServerCommand("image=ubuntu_jammy root-volume=block:{{ .Snapshot.ID }} additional-volumes.0=block:{{ .Snapshot.ID }} stopped=true"),
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
 				testServerSBSVolumeSize("0", 20),
@@ -226,7 +291,9 @@ func Test_CreateServer(t *testing.T) {
 
 		t.Run("valid additional block volumes", core.Test(&core.TestConfig{
 			Commands: instance.GetCommands(),
-			Cmd:      testServerCommand("image=ubuntu_jammy additional-volumes.0=b:1G additional-volumes.1=b:5G additional-volumes.2=b:10G stopped=true"),
+			Cmd: testServerCommand(
+				"image=ubuntu_jammy additional-volumes.0=b:1G additional-volumes.1=b:5G additional-volumes.2=b:10G stopped=true",
+			),
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
 				testServerSBSVolumeSize("1", 1),
@@ -244,7 +311,9 @@ func Test_CreateServer(t *testing.T) {
 			BeforeFunc: core.BeforeFuncCombine(
 				createSbsVolume("Volume", 20),
 			),
-			Cmd: testServerCommand("image=ubuntu_jammy additional-volumes.0={{.Volume.ID}} stopped=true"),
+			Cmd: testServerCommand(
+				"image=ubuntu_jammy additional-volumes.0={{.Volume.ID}} stopped=true",
+			),
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
@@ -331,7 +400,9 @@ func Test_CreateServer(t *testing.T) {
 				instance.GetCommands(),
 				block.GetCommands(),
 			),
-			Cmd: testServerCommand("image=ubuntu_jammy root-volume=sbs:20GB:15000 stopped=true --debug"),
+			Cmd: testServerCommand(
+				"image=ubuntu_jammy root-volume=sbs:20GB:15000 stopped=true --debug",
+			),
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
@@ -341,7 +412,11 @@ func Test_CreateServer(t *testing.T) {
 
 					rootVolume, rootVolumeExists := server.Volumes["0"]
 					assert.True(t, rootVolumeExists)
-					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, rootVolume.VolumeType)
+					assert.Equal(
+						t,
+						instanceSDK.VolumeServerVolumeTypeSbsVolume,
+						rootVolume.VolumeType,
+					)
 
 					api := blockSDK.NewAPI(ctx.Client)
 					vol, err := api.WaitForVolume(&blockSDK.WaitForVolumeRequest{
@@ -436,7 +511,9 @@ func Test_CreateServer(t *testing.T) {
 
 		t.Run("with ipv6", core.Test(&core.TestConfig{
 			Commands: instance.GetCommands(),
-			Cmd:      testServerCommand("ip=ipv6 dynamic-ip-required=false -w"), // IPv6 is created at runtime
+			Cmd: testServerCommand(
+				"ip=ipv6 dynamic-ip-required=false -w",
+			), // IPv6 is created at runtime
 			Check: core.TestCheckCombine(
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
 					t.Helper()
@@ -452,7 +529,9 @@ func Test_CreateServer(t *testing.T) {
 
 		t.Run("with ipv6 and dynamic ip", core.Test(&core.TestConfig{
 			Commands: instance.GetCommands(),
-			Cmd:      testServerCommand("dynamic-ip-required=true ip=ipv6 -w"), // IPv6 is created at runtime
+			Cmd: testServerCommand(
+				"dynamic-ip-required=true ip=ipv6 -w",
+			), // IPv6 is created at runtime
 			Check: core.TestCheckCombine(
 				core.TestCheckExitCode(0),
 				func(t *testing.T, ctx *core.CheckFuncCtx) {
@@ -542,7 +621,9 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid total local volumes size: too low 2", core.Test(&core.TestConfig{
 		Commands: instance.GetCommands(),
-		Cmd:      testServerCommand("image=ubuntu_jammy root-volume=l:5GB additional-volumes.0=block:10GB"),
+		Cmd: testServerCommand(
+			"image=ubuntu_jammy root-volume=l:5GB additional-volumes.0=block:10GB",
+		),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -563,7 +644,9 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid total local volumes size: too high 1", core.Test(&core.TestConfig{
 		Commands: instance.GetCommands(),
-		Cmd:      testServerCommand("image=ubuntu_jammy root-volume=local:10GB additional-volumes.0=local:20GB"),
+		Cmd: testServerCommand(
+			"image=ubuntu_jammy root-volume=local:10GB additional-volumes.0=local:20GB",
+		),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -584,7 +667,9 @@ func Test_CreateServerErrors(t *testing.T) {
 	t.Run("Error: invalid total local volumes size: too high 3", core.Test(&core.TestConfig{
 		Commands:   instance.GetCommands(),
 		BeforeFunc: createVolume("Volume", 20, instanceSDK.VolumeVolumeTypeLSSD),
-		Cmd:        testServerCommand("image=ubuntu_jammy root-volume={{ .Volume.ID }} additional-volumes.0=local:10GB"),
+		Cmd: testServerCommand(
+			"image=ubuntu_jammy root-volume={{ .Volume.ID }} additional-volumes.0=local:10GB",
+		),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -595,7 +680,9 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid root volume size", core.Test(&core.TestConfig{
 		Commands: instance.GetCommands(),
-		Cmd:      testServerCommand("image=ubuntu_jammy root-volume=local:2GB additional-volumes.0=local:18GB"),
+		Cmd: testServerCommand(
+			"image=ubuntu_jammy root-volume=local:2GB additional-volumes.0=local:18GB",
+		),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -617,7 +704,9 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid root volume ID", core.Test(&core.TestConfig{
 		Commands: instance.GetCommands(),
-		Cmd:      testServerCommand("image=ubuntu_jammy root-volume=29da9ad9-e759-4a56-82c8-f0607f93055c"),
+		Cmd: testServerCommand(
+			"image=ubuntu_jammy root-volume=29da9ad9-e759-4a56-82c8-f0607f93055c",
+		),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -626,9 +715,16 @@ func Test_CreateServerErrors(t *testing.T) {
 	}))
 
 	t.Run("Error: already attached additional volume ID", core.Test(&core.TestConfig{
-		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("name=cli-test image=ubuntu_jammy root-volume=l:10G additional-volumes.0=l:10G stopped=true")),
-		Cmd:        testServerCommand(`image=ubuntu_jammy root-volume=l:10G additional-volumes.0={{ (index .Server.Volumes "1").ID }} stopped=true`),
+		Commands: instance.GetCommands(),
+		BeforeFunc: core.ExecStoreBeforeCmd(
+			"Server",
+			testServerCommand(
+				"name=cli-test image=ubuntu_jammy root-volume=l:10G additional-volumes.0=l:10G stopped=true",
+			),
+		),
+		Cmd: testServerCommand(
+			`image=ubuntu_jammy root-volume=l:10G additional-volumes.0={{ (index .Server.Volumes "1").ID }} stopped=true`,
+		),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -649,7 +745,9 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid root volume snapshot ID", core.Test(&core.TestConfig{
 		Commands: instance.GetCommands(),
-		Cmd:      testServerCommand("image=ubuntu_jammy root-volume=local:29da9ad9-e759-4a56-82c8-f0607f93055c"),
+		Cmd: testServerCommand(
+			"image=ubuntu_jammy root-volume=local:29da9ad9-e759-4a56-82c8-f0607f93055c",
+		),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -659,7 +757,9 @@ func Test_CreateServerErrors(t *testing.T) {
 
 	t.Run("Error: invalid additional volume snapshot ID", core.Test(&core.TestConfig{
 		Commands: instance.GetCommands(),
-		Cmd:      testServerCommand("image=ubuntu_jammy additional-volumes.0=block:29da9ad9-e759-4a56-82c8-f0607f93055c"),
+		Cmd: testServerCommand(
+			"image=ubuntu_jammy additional-volumes.0=block:29da9ad9-e759-4a56-82c8-f0607f93055c",
+		),
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(1),
@@ -739,10 +839,16 @@ func Test_CreateServerScratchStorage(t *testing.T) {
 				if !exist {
 					t.Fatalf("Expected an additional scratch volume, found none")
 				}
-				assert.Equal(t, instanceSDK.VolumeServerVolumeTypeScratch, additionalVolume.VolumeType)
+				assert.Equal(
+					t,
+					instanceSDK.VolumeServerVolumeTypeScratch,
+					additionalVolume.VolumeType,
+				)
 			},
 		),
-		AfterFunc:       core.ExecAfterCmd("scw instance server delete {{ .CmdResult.ID }} zone=fr-par-2 with-volumes=all with-ip=true force-shutdown=true"),
+		AfterFunc: core.ExecAfterCmd(
+			"scw instance server delete {{ .CmdResult.ID }} zone=fr-par-2 with-volumes=all with-ip=true force-shutdown=true",
+		),
 		DisableParallel: true,
 	}))
 }
