@@ -33,7 +33,11 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 					require.NoError(t, ctx.Err)
 					resp := testhelpers.Value[*instanceSDK.AttachVolumeResponse](t, ctx.Result)
 					addedVolume := testhelpers.MapTValue(t, resp.Server.Volumes, "1")
-					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeSbsVolume, addedVolume.VolumeType)
+					assert.Equal(
+						t,
+						instanceSDK.VolumeServerVolumeTypeSbsVolume,
+						addedVolume.VolumeType,
+					)
 				},
 				testAttachVolumeServerSBSVolumeSize("0", 10),
 				testAttachVolumeServerSBSVolumeSize("1", 10),
@@ -55,7 +59,12 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 					require.NoError(t, ctx.Err)
 					resp := testhelpers.Value[*instanceSDK.AttachVolumeResponse](t, ctx.Result)
 					addedVolume := testhelpers.MapTValue(t, resp.Server.Volumes, "1")
-					assert.Equal(t, 10*scw.GB, instance.SizeValue(addedVolume.Size), "Size of volume should be 10 GB")
+					assert.Equal(
+						t,
+						10*scw.GB,
+						instance.SizeValue(addedVolume.Size),
+						"Size of volume should be 10 GB",
+					)
 					assert.Equal(t, instanceSDK.VolumeServerVolumeTypeLSSD, addedVolume.VolumeType)
 				},
 				testAttachVolumeServerSBSVolumeSize("0", 10),
@@ -82,8 +91,11 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 				block.GetCommands(),
 				instance.GetCommands(),
 			),
-			BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-jammy additional-volumes.0=block:10G")),
-			Cmd:        `scw instance server detach-volume volume-id={{ (index .Server.Volumes "1").ID }}`,
+			BeforeFunc: core.ExecStoreBeforeCmd(
+				"Server",
+				testServerCommand("stopped=true image=ubuntu-jammy additional-volumes.0=block:10G"),
+			),
+			Cmd: `scw instance server detach-volume volume-id={{ (index .Server.Volumes "1").ID }}`,
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				require.NoError(t, ctx.Err)
@@ -93,7 +105,9 @@ func Test_ServerVolumeUpdate(t *testing.T) {
 				assert.Len(t, ctx.Result.(*instanceSDK.DetachVolumeResponse).Server.Volumes, 1)
 			},
 			AfterFunc: core.AfterFuncCombine(
-				core.ExecAfterCmd(`scw block volume wait terminal-status=available {{ (index .Server.Volumes "1").ID }}`),
+				core.ExecAfterCmd(
+					`scw block volume wait terminal-status=available {{ (index .Server.Volumes "1").ID }}`,
+				),
 				core.ExecAfterCmd(`scw block volume delete {{ (index .Server.Volumes "1").ID }}`),
 				deleteServer("Server"),
 			),
@@ -161,16 +175,21 @@ func Test_ServerUpdateCustom(t *testing.T) {
 			createIP("IP2"),
 
 			// Attach IP1 to Server.
-			core.ExecStoreBeforeCmd("UpdatedServer", "scw instance server update {{ .Server.ID }} ip={{ .IP1.Address }}"),
+			core.ExecStoreBeforeCmd(
+				"UpdatedServer",
+				"scw instance server update {{ .Server.ID }} ip={{ .IP1.Address }}",
+			),
 		),
 		Cmd: "scw instance server update {{ .Server.ID }} ip={{ .IP2.Address }}",
 		Check: core.TestCheckCombine(
 			func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				// Test that the Server WAS attached to IP1.
-				assert.Equal(t,
+				assert.Equal(
+					t,
 					ctx.Meta["IP1"].(*instanceSDK.IP).Address,
-					ctx.Meta["UpdatedServer"].(*instanceSDK.UpdateServerResponse).Server.PublicIP.Address)
+					ctx.Meta["UpdatedServer"].(*instanceSDK.UpdateServerResponse).Server.PublicIP.Address,
+				)
 				// Test that the Server IS attached to IP2.
 				assert.Equal(t,
 					ctx.Meta["IP2"].(*instanceSDK.IP).Address,
@@ -185,54 +204,70 @@ func Test_ServerUpdateCustom(t *testing.T) {
 	}))
 
 	// Placement group cases.
-	t.Run("Update server placement-group-id from server with placement-group-id", core.Test(&core.TestConfig{
-		Commands: instance.GetCommands(),
-		BeforeFunc: core.BeforeFuncCombine(
-			createPlacementGroup("PlacementGroup1"),
-			createPlacementGroup("PlacementGroup2"),
-			core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-jammy placement-group-id={{ .PlacementGroup1.ID }}")),
-		),
-		Cmd: "scw instance server update {{ .Server.ID }} placement-group-id={{ .PlacementGroup2.ID }}",
-		Check: core.TestCheckCombine(
-			core.TestCheckExitCode(0),
-			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				t.Helper()
-				assert.Equal(t,
-					ctx.Meta["PlacementGroup2"].(*instanceSDK.PlacementGroup).ID,
-					ctx.Result.(*instanceSDK.UpdateServerResponse).Server.PlacementGroup.ID)
-			},
-		),
-		AfterFunc: core.AfterFuncCombine(
-			deleteServer("Server"),
-			deletePlacementGroup("PlacementGroup1"),
-			deletePlacementGroup("PlacementGroup2"),
-		),
-	}))
+	t.Run(
+		"Update server placement-group-id from server with placement-group-id",
+		core.Test(&core.TestConfig{
+			Commands: instance.GetCommands(),
+			BeforeFunc: core.BeforeFuncCombine(
+				createPlacementGroup("PlacementGroup1"),
+				createPlacementGroup("PlacementGroup2"),
+				core.ExecStoreBeforeCmd(
+					"Server",
+					testServerCommand(
+						"stopped=true image=ubuntu-jammy placement-group-id={{ .PlacementGroup1.ID }}",
+					),
+				),
+			),
+			Cmd: "scw instance server update {{ .Server.ID }} placement-group-id={{ .PlacementGroup2.ID }}",
+			Check: core.TestCheckCombine(
+				core.TestCheckExitCode(0),
+				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					t.Helper()
+					assert.Equal(t,
+						ctx.Meta["PlacementGroup2"].(*instanceSDK.PlacementGroup).ID,
+						ctx.Result.(*instanceSDK.UpdateServerResponse).Server.PlacementGroup.ID)
+				},
+			),
+			AfterFunc: core.AfterFuncCombine(
+				deleteServer("Server"),
+				deletePlacementGroup("PlacementGroup1"),
+				deletePlacementGroup("PlacementGroup2"),
+			),
+		}),
+	)
 
 	// Security group cases.
-	t.Run("Update server security-group-id from server with security-group-id", core.Test(&core.TestConfig{
-		Commands: instance.GetCommands(),
-		BeforeFunc: core.BeforeFuncCombine(
-			createSecurityGroup("SecurityGroup1"),
-			createSecurityGroup("SecurityGroup2"),
-			core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-jammy security-group-id={{ .SecurityGroup1.ID }}")),
-		),
-		Cmd: "scw instance server update {{ .Server.ID }} security-group-id={{ .SecurityGroup2.ID }}",
-		Check: core.TestCheckCombine(
-			core.TestCheckExitCode(0),
-			func(t *testing.T, ctx *core.CheckFuncCtx) {
-				t.Helper()
-				assert.Equal(t,
-					ctx.Meta["SecurityGroup2"].(*instanceSDK.SecurityGroup).ID,
-					ctx.Result.(*instanceSDK.UpdateServerResponse).Server.SecurityGroup.ID)
-			},
-		),
-		AfterFunc: core.AfterFuncCombine(
-			deleteServer("Server"),
-			deleteSecurityGroup("SecurityGroup1"),
-			deleteSecurityGroup("SecurityGroup2"),
-		),
-	}))
+	t.Run(
+		"Update server security-group-id from server with security-group-id",
+		core.Test(&core.TestConfig{
+			Commands: instance.GetCommands(),
+			BeforeFunc: core.BeforeFuncCombine(
+				createSecurityGroup("SecurityGroup1"),
+				createSecurityGroup("SecurityGroup2"),
+				core.ExecStoreBeforeCmd(
+					"Server",
+					testServerCommand(
+						"stopped=true image=ubuntu-jammy security-group-id={{ .SecurityGroup1.ID }}",
+					),
+				),
+			),
+			Cmd: "scw instance server update {{ .Server.ID }} security-group-id={{ .SecurityGroup2.ID }}",
+			Check: core.TestCheckCombine(
+				core.TestCheckExitCode(0),
+				func(t *testing.T, ctx *core.CheckFuncCtx) {
+					t.Helper()
+					assert.Equal(t,
+						ctx.Meta["SecurityGroup2"].(*instanceSDK.SecurityGroup).ID,
+						ctx.Result.(*instanceSDK.UpdateServerResponse).Server.SecurityGroup.ID)
+				},
+			),
+			AfterFunc: core.AfterFuncCombine(
+				deleteServer("Server"),
+				deleteSecurityGroup("SecurityGroup1"),
+				deleteSecurityGroup("SecurityGroup2"),
+			),
+		}),
+	)
 
 	// Volumes cases.
 	t.Run("Volumes", func(t *testing.T) {
@@ -258,17 +293,24 @@ func Test_ServerUpdateCustom(t *testing.T) {
 				block.GetCommands(),
 				instance.GetCommands(),
 			),
-			BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-jammy additional-volumes.0=block:10G")),
-			Cmd:        `scw instance server update {{ .Server.ID }} volume-ids=none`,
+			BeforeFunc: core.ExecStoreBeforeCmd(
+				"Server",
+				testServerCommand("stopped=true image=ubuntu-jammy additional-volumes.0=block:10G"),
+			),
+			Cmd: `scw instance server update {{ .Server.ID }} volume-ids=none`,
 			Check: func(t *testing.T, ctx *core.CheckFuncCtx) {
 				t.Helper()
 				require.NoError(t, ctx.Err)
 				assert.Empty(t, ctx.Result.(*instanceSDK.UpdateServerResponse).Server.Volumes)
 			},
 			AfterFunc: core.AfterFuncCombine(
-				core.ExecAfterCmd(`scw block volume wait terminal-status=available {{ (index .Server.Volumes "0").ID }}`),
+				core.ExecAfterCmd(
+					`scw block volume wait terminal-status=available {{ (index .Server.Volumes "0").ID }}`,
+				),
 				core.ExecAfterCmd(`scw block volume delete {{ (index .Server.Volumes "0").ID }}`),
-				core.ExecAfterCmd(`scw block volume wait terminal-status=available {{ (index .Server.Volumes "1").ID }}`),
+				core.ExecAfterCmd(
+					`scw block volume wait terminal-status=available {{ (index .Server.Volumes "1").ID }}`,
+				),
 				core.ExecAfterCmd(`scw block volume delete {{ (index .Server.Volumes "1").ID }}`),
 				deleteServer("Server"),
 			),
@@ -282,9 +324,12 @@ func Test_ServerDelete(t *testing.T) {
 	interactive.IsInteractive = true
 
 	t.Run("with all volumes", core.Test(&core.TestConfig{
-		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true additional-volumes.0=block:10G")),
-		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=all`,
+		Commands: instance.GetCommands(),
+		BeforeFunc: core.ExecStoreBeforeCmd(
+			"Server",
+			testServerCommand("stopped=true additional-volumes.0=block:10G"),
+		),
+		Cmd: `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=all`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
@@ -293,14 +338,19 @@ func Test_ServerDelete(t *testing.T) {
 	}))
 
 	t.Run("only block volumes", core.Test(&core.TestConfig{
-		Commands:   instance.GetCommands(),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true root-volume=l:20G additional-volumes.0=block:10G")),
-		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=block`,
+		Commands: instance.GetCommands(),
+		BeforeFunc: core.ExecStoreBeforeCmd(
+			"Server",
+			testServerCommand("stopped=true root-volume=l:20G additional-volumes.0=block:10G"),
+		),
+		Cmd: `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=block`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 		),
-		AfterFunc:       core.ExecAfterCmd(`scw instance volume delete {{ (index .Server.Volumes "0").ID }}`),
+		AfterFunc: core.ExecAfterCmd(
+			`scw instance volume delete {{ (index .Server.Volumes "0").ID }}`,
+		),
 		DisableParallel: true,
 	}))
 
@@ -309,14 +359,19 @@ func Test_ServerDelete(t *testing.T) {
 			block.GetCommands(),
 			instance.GetCommands(),
 		),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true additional-volumes.0=block:10G")),
-		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=local`,
+		BeforeFunc: core.ExecStoreBeforeCmd(
+			"Server",
+			testServerCommand("stopped=true additional-volumes.0=block:10G"),
+		),
+		Cmd: `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=local`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
 		),
 		AfterFunc: core.AfterFuncCombine(
-			core.ExecAfterCmd(`scw block volume wait terminal-status=available {{ (index .Server.Volumes "1").ID }}`),
+			core.ExecAfterCmd(
+				`scw block volume wait terminal-status=available {{ (index .Server.Volumes "1").ID }}`,
+			),
 			core.ExecAfterCmd(`scw block volume delete {{ (index .Server.Volumes "1").ID }}`),
 		),
 		DisableParallel: true,
@@ -327,8 +382,11 @@ func Test_ServerDelete(t *testing.T) {
 			block.GetCommands(),
 			instance.GetCommands(),
 		),
-		BeforeFunc: core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true root-volume=l:20G additional-volumes.0=block:10G")),
-		Cmd:        `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=none`,
+		BeforeFunc: core.ExecStoreBeforeCmd(
+			"Server",
+			testServerCommand("stopped=true root-volume=l:20G additional-volumes.0=block:10G"),
+		),
+		Cmd: `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=none`,
 		Check: core.TestCheckCombine(
 			core.TestCheckGolden(),
 			core.TestCheckExitCode(0),
@@ -355,9 +413,14 @@ func Test_ServerDelete(t *testing.T) {
 			block.GetCommands(),
 		),
 		BeforeFunc: core.BeforeFuncCombine(
-			core.ExecStoreBeforeCmd("BlockVolume", "scw block volume create perf-iops=5000 from-empty.size=10G name=cli-test-server-delete-with-sbs-volumes"),
+			core.ExecStoreBeforeCmd(
+				"BlockVolume",
+				"scw block volume create perf-iops=5000 from-empty.size=10G name=cli-test-server-delete-with-sbs-volumes",
+			),
 			core.ExecStoreBeforeCmd("Server", testServerCommand("stopped=true image=ubuntu-jammy")),
-			core.ExecBeforeCmd("scw instance server attach-volume server-id={{ .Server.ID }} volume-id={{ .BlockVolume.ID }}"),
+			core.ExecBeforeCmd(
+				"scw instance server attach-volume server-id={{ .Server.ID }} volume-id={{ .BlockVolume.ID }}",
+			),
 		),
 		Cmd: `scw instance server delete {{ .Server.ID }} with-ip=true with-volumes=all`,
 		Check: core.TestCheckCombine(
