@@ -59,7 +59,11 @@ func deleteServer(metaKey string) core.AfterFunc {
 			}
 		}
 
-		return core.ExecAfterCmd("scw instance server delete {{ ." + metaKey + ".ID }} with-ip=true with-volumes=all")(ctx)
+		return core.ExecAfterCmd(
+			"scw instance server delete {{ ." + metaKey + ".ID }} with-ip=true with-volumes=all",
+		)(
+			ctx,
+		)
 	}
 }
 
@@ -71,9 +75,17 @@ func deleteServer(metaKey string) core.AfterFunc {
 // register it in the context Meta at metaKey.
 //
 //nolint:unparam
-func createVolume(metaKey string, sizeInGb int, volumeType instance.VolumeVolumeType) core.BeforeFunc {
+func createVolume(
+	metaKey string,
+	sizeInGb int,
+	volumeType instance.VolumeVolumeType,
+) core.BeforeFunc {
 	return func(ctx *core.BeforeFuncCtx) error {
-		cmd := fmt.Sprintf("scw instance volume create name=cli-test size=%dGB volume-type=%s", sizeInGb, volumeType)
+		cmd := fmt.Sprintf(
+			"scw instance volume create name=cli-test size=%dGB volume-type=%s",
+			sizeInGb,
+			volumeType,
+		)
 		res := ctx.ExecuteCmd(strings.Split(cmd, " "))
 		createVolumeResponse := res.(*instance.CreateVolumeResponse)
 		ctx.Meta[metaKey] = createVolumeResponse.Volume
@@ -93,7 +105,11 @@ func deleteVolume(metaKey string) core.AfterFunc { //nolint: unparam
 //nolint:unparam
 func createSbsVolume(metaKey string, sizeInGb int) core.BeforeFunc {
 	return func(ctx *core.BeforeFuncCtx) error {
-		cmd := fmt.Sprintf("scw block volume create name=%s from-empty.size=%dGB perf-iops=5000 -w", ctx.T.Name(), sizeInGb)
+		cmd := fmt.Sprintf(
+			"scw block volume create name=%s from-empty.size=%dGB perf-iops=5000 -w",
+			ctx.T.Name(),
+			sizeInGb,
+		)
 		res := ctx.ExecuteCmd(strings.Split(cmd, " "))
 		volume := res.(*block.Volume)
 		ctx.Meta[metaKey] = volume
@@ -196,7 +212,11 @@ func createNIC() core.BeforeFunc {
 
 // testServerSBSVolumeSize checks the size of a volume in an instance server.
 // The server must be returned by the given instanceFetcher function
-func testServerFetcherSBSVolumeSize(volumeKey string, sizeInGB int, serverFetcher func(t *testing.T, ctx *core.CheckFuncCtx) *instance.Server) core.TestCheck {
+func testServerFetcherSBSVolumeSize(
+	volumeKey string,
+	sizeInGB int,
+	serverFetcher func(t *testing.T, ctx *core.CheckFuncCtx) *instance.Server,
+) core.TestCheck {
 	return func(t *testing.T, ctx *core.CheckFuncCtx) {
 		t.Helper()
 		server := serverFetcher(t, ctx)
@@ -208,33 +228,51 @@ func testServerFetcherSBSVolumeSize(volumeKey string, sizeInGB int, serverFetche
 		})
 		require.NoError(t, err)
 
-		require.Equal(t, scw.Size(sizeInGB)*scw.GB, volume.Size, "Size of volume should be %d GB", sizeInGB)
+		require.Equal(
+			t,
+			scw.Size(sizeInGB)*scw.GB,
+			volume.Size,
+			"Size of volume should be %d GB",
+			sizeInGB,
+		)
 	}
 }
 
 // testServerSBSVolumeSize checks the size of a volume in Result's server.
 // The server must be returned as result of the test's Cmd
 func testServerSBSVolumeSize(volumeKey string, sizeInGB int) core.TestCheck {
-	return testServerFetcherSBSVolumeSize(volumeKey, sizeInGB, func(t *testing.T, ctx *core.CheckFuncCtx) *instance.Server {
-		t.Helper()
+	return testServerFetcherSBSVolumeSize(
+		volumeKey,
+		sizeInGB,
+		func(t *testing.T, ctx *core.CheckFuncCtx) *instance.Server {
+			t.Helper()
 
-		return testhelpers.Value[*instance.Server](t, ctx.Result)
-	})
+			return testhelpers.Value[*instance.Server](t, ctx.Result)
+		},
+	)
 }
 
 // testAttachVolumeServerSBSVolumeSize is the same as testServerSBSVolumeSize but the test's Cmd must be "scw instance server attach-volume"
 func testAttachVolumeServerSBSVolumeSize(volumeKey string, sizeInGB int) core.TestCheck {
-	return testServerFetcherSBSVolumeSize(volumeKey, sizeInGB, func(t *testing.T, ctx *core.CheckFuncCtx) *instance.Server {
-		t.Helper()
+	return testServerFetcherSBSVolumeSize(
+		volumeKey,
+		sizeInGB,
+		func(t *testing.T, ctx *core.CheckFuncCtx) *instance.Server {
+			t.Helper()
 
-		return testhelpers.Value[*instance.AttachVolumeResponse](t, ctx.Result).Server
-	})
+			return testhelpers.Value[*instance.AttachVolumeResponse](t, ctx.Result).Server
+		},
+	)
 }
 
 func testServerUpdateServerSBSVolumeSize(volumeKey string, sizeInGB int) core.TestCheck {
-	return testServerFetcherSBSVolumeSize(volumeKey, sizeInGB, func(t *testing.T, ctx *core.CheckFuncCtx) *instance.Server {
-		t.Helper()
+	return testServerFetcherSBSVolumeSize(
+		volumeKey,
+		sizeInGB,
+		func(t *testing.T, ctx *core.CheckFuncCtx) *instance.Server {
+			t.Helper()
 
-		return testhelpers.Value[*instance.UpdateServerResponse](t, ctx.Result).Server
-	})
+			return testhelpers.Value[*instance.UpdateServerResponse](t, ctx.Result).Server
+		},
+	)
 }
