@@ -2,6 +2,7 @@ package jobs
 
 import (
 	"context"
+	"errors"
 	"fmt"
 
 	"github.com/scaleway/scaleway-cli/v2/core"
@@ -14,7 +15,7 @@ func definitionStartBuilder(c *core.Command) *core.Command {
 	c.WaitFunc = func(ctx context.Context, argsI, respI interface{}) (interface{}, error) {
 		api := jobs.NewAPI(core.ExtractClient(ctx))
 		args := argsI.(*jobs.StartJobDefinitionRequest)
-		resp := respI.(*jobs.JobRun)
+		resp := respI.(*jobs.StartJobDefinitionResponse)
 
 		jobDefinition, err := api.GetJobDefinition(&jobs.GetJobDefinitionRequest{
 			Region:          args.Region,
@@ -24,9 +25,13 @@ func definitionStartBuilder(c *core.Command) *core.Command {
 			return nil, fmt.Errorf("failed to fetch job definition for timeout: %w", err)
 		}
 
+		if len(resp.JobRuns) == 0 {
+			return nil, errors.New("no job run found")
+		}
+
 		return api.WaitForJobRun(&jobs.WaitForJobRunRequest{
 			Region:        args.Region,
-			JobRunID:      resp.ID,
+			JobRunID:      resp.JobRuns[0].ID,
 			Timeout:       jobDefinition.JobTimeout.ToTimeDuration(),
 			RetryInterval: core.DefaultRetryInterval,
 		})
