@@ -12,16 +12,18 @@ import (
 )
 
 func versionListBuilder(c *core.Command) *core.Command {
-	c.AddInterceptors(func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
-		originalRes, err := runner(ctx, argsI)
-		if err != nil {
-			return nil, err
-		}
+	c.AddInterceptors(
+		func(ctx context.Context, argsI interface{}, runner core.CommandRunner) (interface{}, error) {
+			originalRes, err := runner(ctx, argsI)
+			if err != nil {
+				return nil, err
+			}
 
-		versionsResponse := originalRes.(*k8s.ListVersionsResponse)
+			versionsResponse := originalRes.(*k8s.ListVersionsResponse)
 
-		return versionsResponse.Versions, nil
-	})
+			return versionsResponse.Versions, nil
+		},
+	)
 
 	return c
 }
