@@ -83,7 +83,8 @@ func certificateCreateBuilder(c *core.Command) *core.Command {
 				return nil, err
 			}
 
-			if len(res.(*lb.Certificate).LB.Tags) != 0 && res.(*lb.Certificate).LB.Tags[0] == kapsuleTag {
+			if len(res.(*lb.Certificate).LB.Tags) != 0 &&
+				res.(*lb.Certificate).LB.Tags[0] == kapsuleTag {
 				return warningKapsuleTaggedMessageView(), nil
 			}
 
@@ -105,7 +106,8 @@ func certificateCreateBuilder(c *core.Command) *core.Command {
 				return nil, err
 			}
 
-			if len(res.(*lb.Certificate).LB.Tags) != 0 && res.(*lb.Certificate).LB.Tags[0] == kapsuleTag {
+			if len(res.(*lb.Certificate).LB.Tags) != 0 &&
+				res.(*lb.Certificate).LB.Tags[0] == kapsuleTag {
 				return warningKapsuleTaggedMessageView(), nil
 			}
 
@@ -113,8 +115,12 @@ func certificateCreateBuilder(c *core.Command) *core.Command {
 		}
 
 		return nil, &core.CliError{
-			Err:  errors.New("missing required argument"),
-			Hint: fmt.Sprintf("You need to specify %s or %s", leCommonNameArgSpecs.Name, customeCertificateArgSpecs.Name),
+			Err: errors.New("missing required argument"),
+			Hint: fmt.Sprintf(
+				"You need to specify %s or %s",
+				leCommonNameArgSpecs.Name,
+				customeCertificateArgSpecs.Name,
+			),
 			Code: 1,
 		}
 	}
