@@ -11,10 +11,13 @@ import (
 )
 
 var logStatusMarshalSpecs = human.EnumMarshalSpecs{
-	rdb.InstanceLogStatusUnknown:  &human.EnumMarshalSpec{Attribute: color.Faint, Value: "unknown"},
-	rdb.InstanceLogStatusReady:    &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "ready"},
-	rdb.InstanceLogStatusCreating: &human.EnumMarshalSpec{Attribute: color.FgBlue, Value: "creating"},
-	rdb.InstanceLogStatusError:    &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "error"},
+	rdb.InstanceLogStatusUnknown: &human.EnumMarshalSpec{Attribute: color.Faint, Value: "unknown"},
+	rdb.InstanceLogStatusReady:   &human.EnumMarshalSpec{Attribute: color.FgGreen, Value: "ready"},
+	rdb.InstanceLogStatusCreating: &human.EnumMarshalSpec{
+		Attribute: color.FgBlue,
+		Value:     "creating",
+	},
+	rdb.InstanceLogStatusError: &human.EnumMarshalSpec{Attribute: color.FgRed, Value: "error"},
 }
 
 func logPrepareBuilder(c *core.Command) *core.Command {
