@@ -51,7 +51,8 @@ func gatewayNetworkDeleteBuilder(c *core.Command) *core.Command {
 		if err != nil {
 			notFoundError := &scw.ResourceNotFoundError{}
 			responseError := &scw.ResponseError{}
-			if errors.As(err, &responseError) && responseError.StatusCode == http.StatusNotFound || errors.As(err, &notFoundError) {
+			if errors.As(err, &responseError) && responseError.StatusCode == http.StatusNotFound ||
+				errors.As(err, &notFoundError) {
 				return &core.SuccessResult{
 					Resource: "gateway-network",
 					Verb:     "delete",
