@@ -16,9 +16,17 @@ func GetCommands() *core.Commands {
 		}
 	}
 
-	human.RegisterMarshalerFunc(vpcgw.GatewayNetworkStatus(""), human.EnumMarshalFunc(gatewayNetworkStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(vpcgw.GatewayStatus(""), human.EnumMarshalFunc(gatewayStatusMarshalSpecs))
-	human.RegisterMarshalerFunc(vpcgw.Gateway{}, gatewayMarshalerFunc)
+	cmds.MustFind("vpc-gw").Groups = []string{"network"}
+
+	human.RegisterMarshalerFunc(
+		vpcgw.GatewayNetworkStatus(""),
+		human.EnumMarshalFunc(gatewayNetworkStatusMarshalSpecs))
+	human.RegisterMarshalerFunc(
+		vpcgw.GatewayStatus(""),
+		human.EnumMarshalFunc(gatewayStatusMarshalSpecs))
+	human.RegisterMarshalerFunc(
+		vpcgw.Gateway{},
+		gatewayMarshalerFunc)
 
 	cmds.MustFind("vpc-gw", "gateway-type", "list").Override(vpcgwGatewayTypeListBuilder)
 	cmds.MustFind("vpc-gw", "gateway", "create").Override(gatewayCreateBuilder)
